// ignore_for_file: constant_identifier_names

import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:karot_components/button/karot_button.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/text_enum.dart';
import 'package:karot_components/constant/theme.dart';
import 'package:karot_components/label/karot_label.dart';
import 'package:karot_components/label/karot_note.dart';
import 'package:lottie/lottie.dart';

import '../karot_ultilities.dart';

class KRCard extends StatelessWidget {
  final String assetURL;
  final String title;
  final String bodyText;
  final int backgroundColor;
  final int textColor;
  final VoidCallback onDismissTap;

  const KRCard({
    Key? key,
    required this.assetURL,
    required this.onDismissTap,
    required this.title,
    required this.bodyText,
    this.backgroundColor = KRTheme.DEFAULT_LIGHT_COLOR,
    this.textColor = KRTheme.DEFAULT_DARK_COLOR,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
        width: MediaQuery.of(context).size.width,
        padding: const EdgeInsets.all(KRTheme.PADDING),
        margin: const EdgeInsets.all(KRTheme.DIALOG_MARGIN_FROM_SCREEN),
        decoration: BoxDecoration(
            boxShadow: [
              BoxShadow(
                color: Colors.grey.withOpacity(0.1),
                spreadRadius: 3,
                blurRadius: 3,
                offset: const Offset(0, 0), // changes position of shadow
              ),
            ],
            color: Color(backgroundColor),
            borderRadius: BorderRadius.circular(30)),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: [
            // Lottie.asset(assetURL, width: 150, height: 150, repeat: false),
            KRLabel(text: title, isBold: true, size: KRTextSize.title),
            KRNote(
                text: bodyText,
                textAlign: TextAlign.center,
                size: KRTextSize.body),
            const KRGap(height: 40),
            KRButton(
                text: "Close",
                isFull: true,
                isOutline: false,
                isBold: false,
                size: KRButtonSize.large,
                onPress: () {})
          ],
        ));
  }
}
